Einen Peer einer Peer-Gruppe hinzufügen
Der Dynamic Route Server for VPC ist eine Beta-Funktion, die ausgewählten Kunden zu Evaluierungs- und Testzwecken zur Verfügung steht. Der Zugriff ist auf Konten beschränkt, die auf der Whitelist stehen.
Sie können einen Peer, z. B. Firewalls, Router, SD-WAN-Geräte oder ein Transit-Gateway, einer Peer-Gruppe zuordnen, um eine BGP-Sitzung zwischen dem dynamischen Routingserver und dem Peer-Routing-Gerät herzustellen.
Vorbereitende Schritte
Bevor Sie einen Peer einer Peer-Gruppe zuordnen:
- Lesen Sie die Überlegungen zur Planung dynamischer Routenserver.
- Lesen Sie den Abschnitt Bekannte Probleme zu dynamischen Routenservern.
- Stellen Sie sicher, dass Sie eine Peer-Gruppe angelegt haben. Weitere Informationen finden Sie unter Erstellen einer Peer-Gruppe.
- Stellen Sie sicher, dass der Peer-Endpunkt nicht von einem anderen Peer in einer beliebigen Peer-Gruppe des dynamischen Routingservers verwendet wird.
Einen Peer in der Konsole einer Peer-Gruppe hinzufügen
Um einen Peer in der Konsole einer Peer-Gruppe hinzuzufügen, führen Sie die folgenden Schritte aus:
-
Öffnen Sie in Ihrem Browser die IBM Cloud-Konsole und melden Sie sich bei Ihrem Konto an.
-
Wählen Sie das
für das Navigationsmenü aus und klicken Sie anschließend auf
Infrastruktur VPC > Netzwerk > Dynamische Routenserver.
-
Wählen Sie in der Liste den dynamischen Routingserver aus, mit dem Sie arbeiten möchten, und klicken Sie anschließend auf die Registerkarte Peer-Gruppen.
-
Wählen Sie den Namen der Peer-Gruppe aus.
-
Klicken Sie im Abschnitt Peer-Mitglieder auf Erstellen.
-
Geben Sie im Bereich Peer hinzufügen einen Namen für den Peer ein, z. B.
my-peer. -
Geben Sie die Peer-ASN ein, die den Peer im Netzwerk identifiziert.
-
Wählen Sie die Priorität Peer aus. Ein niedrigerer Wert gibt eine höhere Priorität an. Der Standardwert ist 2.
-
Aktivieren Sie den Peer-Status, um eine BGP-Sitzung mit dem Peer herzustellen.
-
Beschreiben Sie, wie der dynamische Routenserver den Peer identifiziert und eine Verbindung zu ihm herstellt. Klicken Sie auf Peer-Netzwerk auswählen, um ein vorhandenes Netzwerk zu verwenden, und wählen Sie anschließend die Peer-VPC, das Subnetz und die reservierte IP-Adresse aus. Alternativ können Sie auf Peer-Netzwerk hinzufügen klicken und die IP-Adresse sowie die Gateway-IP angeben, um ein neues Netzwerk hinzuzufügen.
-
Klicken Sie auf Speichern.
Eine Peer-Gruppe muss mindestens einen Peer enthalten. Um den letzten Peer zu entfernen, löschen Sie die Peer-Gruppe. Durch das Entfernen eines Peers werden auch alle von diesem Peers erlernten Routen gelöscht; dieser Vorgang kann nicht rückgängig gemacht werden.
Hinzufügen eines Peers zu einer Peer-Gruppe über die CLI
Um einen Peer über die CLI einer Peer-Gruppe hinzuzufügen, führen Sie die folgenden Schritte aus:
-
Konfigurieren Sie die Umgebung der Befehlszeilenschnittstelle.
-
Melden Sie sich bei Ihrer CLI-Umgebung an. Nach der Eingabe des Kennworts werden Sie vom System aufgefordert, anzugeben, welches Konto und welche Region verwendet werden soll:
ibmcloud login --sso -
Aktivieren Sie das folgende Feature-Flag:
export IBMCLOUD_IS_FEATURE_DYNAMIC_ROUTE_SERVER=true -
Führen Sie den folgenden Befehl aus:
ibmcloud is dynamic-route-server-peer-group-peer-create DYNAMIC_ROUTE_SERVER --peer-group PEER_GROUP --asn ASN --endpoint-rip ENDPOINT_RIP [--endpoint-rip-subnet ENDPOINT_RIP_SUBNET] [--vpc VPC] | --endpoint-address IP_ADDRESS [--gateway-address IP_ADDRESS] [--name NAME] [--state enabled | disabled] [--priority PRIORITY] [--output JSON] [-q, --quiet]
Dabei gilt:
Die Kennung DYNAMIC_ROUTE_SERVER : des dynamischen Routenservers.
--peer-group : Die Peer-Gruppen-Kennung.
--asn : Die Autonomous-System-Nummer (ASN) des Peers.
--endpoint-rip : Die Port-Kennung der Routen-Schnittstelle.
--endpoint-rip-subnet : Die Subnetz-Kennung, die dem Port der Endpunkt-Routing-Schnittstelle zugeordnet ist.
--vpc : Die dem Endpunkt zugeordnete VPC-Kennung.
--endpoint-address : Die IP-Adresse des Peers.
--gateway-address : Die IP-Adresse des Gateways.
--name : Der Name des Peers.
--state : Der Peer-Status. Entweder: enabled oder disabled. Der Standardwert ist enabled.
--priority : Die Peer-Priorität, von 0 bis 4. Niedrigere Werte haben eine höhere Priorität. Der Standardwert ist 2.
--output : Ausgabe im JSON-Format.
-q, --quiet : Unterdrückt ausführliche Ausgaben.
Befehlsbeispiele
-
Um einen Peer einer Peer-Gruppe hinzuzufügen, führen Sie den folgenden Befehl aus:
ibmcloud is dynamic-route-server-peer-group-peer-create 0717-drs-12345678 --peer-group my-peer-group --asn 65001 --endpoint-address 192.168.10.10 --gateway-address 192.168.10.1 --name my-peer-1 --state enabled --priority 1 --output JSON
Einen Peer über die API einer Peer-Gruppe hinzufügen
Um einen Peer über die API einer Peer-Gruppe hinzuzufügen, führen Sie die folgenden Schritte aus:
-
Richten Sie Ihre API-Umgebung mit den erforderlichen Variablen ein.
-
Speichern Sie alle zusätzlichen Variablen, die in den API-Befehlen verwendet werden sollen. Zum Beispiel:
ResourceGroupId- Suchen Sie die Ressourcengruppen-ID mithilfe des Befehlsget resource groupsund füllen Sie dann die Variable:
export ResourceGroupId=<your_resourcegroup_id> -
Wenn alle Variablen festgelegt sind, fügen Sie den Peer zur Peer-Gruppe hinzu:
curl -X POST \ "$vpc_api_endpoint/v1/dynamic_route_servers/DRS_ID/peer_groups/PEER_GROUP_ID/peers?version=$api_version&generation=2" \ -H "Authorization: Bearer $iam_token" \ -H "Content-Type: application/json" \ -d '{ "asn": 64520, "state": "enabled", "priority": 1, "endpoint": { "address": "10.40.38.2", "gateway": { "address": "10.30.40.5" } } }'
Nächste Schritte
Nachdem Sie nun einen Peer zur Peer-Gruppe hinzugefügt haben, sollten Sie die folgenden Schritte in Betracht ziehen: